translate.services.lookupservice.lookupRequestHandler

Package translate :: Package services :: Module lookupservice :: Class lookupRequestHandler |
[hide private]
[frames] | no frames]

# Class lookupRequestHandler

source code

Sets up the requested file for parsing

Instance Methods | [hide private]
Inherited from `SimpleXMLRPCServer.SimpleXMLRPCRequestHandler`: `do_POST`, `is_rpc_path_valid`, `log_request`, `report_404` Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `address_string`, `date_time_string`, `end_headers`, `handle`, `handle_one_request`, `log_date_time_string`, `log_error`, `log_message`, `parse_request`, `send_error`, `send_header`, `send_response`, `version_string` Inherited from `SocketServer.StreamRequestHandler`: `finish`, `setup` Inherited from `SocketServer.BaseRequestHandler`: `__init__`

Class Variables | [hide private]
Inherited from `SimpleXMLRPCServer.SimpleXMLRPCRequestHandler`: `rpc_paths` Inherited from `BaseHTTPServer.BaseHTTPRequestHandler`: `MessageClass`, `error_message_format`, `monthname`, `protocol_version`, `responses`, `server_version`, `sys_version`, `weekdayname` Inherited from `SocketServer.StreamRequestHandler`: `rbufsize`, `wbufsize`